Module debug_xml

Module debug_xml 

Provide methods and data structures for debug XML documents.

This module is based on libxml/debugXML.h, debugXML.c, and so on in libxml2-v2.11.8.
Please refer to original libxml2 documents also.

Structs

XmlDebugCtxt
XmlShellCtxt
A debugging shell context.
TODO: add the defined function tables.

Functions

xml_bool_to_text
Convenient way to turn bool into text
xml_debug_check_document
Check the document for potential content problems, and output the errors to output
xml_debug_dump_attr
Dumps debug information for the attribute
xml_debug_dump_attr_list
Dumps debug information for the attribute list
xml_debug_dump_document
Dumps debug information for the document, it’s recursive
xml_debug_dump_document_head
Dumps debug information concerning the document, not recursive
xml_debug_dump_dtd
Dumps debug information for the DTD
xml_debug_dump_entities
Dumps debug information for all the entities in use by the document
xml_debug_dump_node
Dumps debug information for the element node, it is recursive
xml_debug_dump_node_list
Dumps debug information for the list of element node, it is recursive
xml_debug_dump_one_node
Dumps debug information for the element node, it is not recursive
xml_debug_dump_string
Dumps information about the string, shorten it if necessary
xml_ls_count_node
Count the children of @node.
xml_ls_one_node
Dump to output the type and name of @node.
xml_shell
Implements the XML shell This allow to load, validate, view, modify and save a document using a environment similar to a UNIX commandline.
xml_shell_print_node
Print node to the output FILE
xml_shell_print_xpath_error
Print the xpath error to libxml default error channel
xml_shell_print_xpath_result
Prints result to the output FILE

Type Aliases

XmlDebugCtxtPtr
XmlShellCmd
This is a generic signature for the XML shell functions.
XmlShellReadlineFunc
This is a generic signature for the XML shell input function.