pub fn xml_ls_one_node<'a>(
output: &mut (impl Write + 'a),
node: Option<XmlGenericNodePtr>,
)Expand description
Dump to output the type and name of @node.
pub fn xml_ls_one_node<'a>(
output: &mut (impl Write + 'a),
node: Option<XmlGenericNodePtr>,
)Dump to output the type and name of @node.