Module dom

Module dom 

Implement Document Object Model (DOM) Level 3 Core.

I will try to maintain compatibility with the libxml2 tree as much as possible.

Currently, full implementation of the specification is not a goal.
For example, I do not plan to provide a feature selection mechanism.

Note

  • The iterators that walk through the nodes of the DOM are not implemented.
    Nodes are not restricted to only one source, and each node can modify the whole DOM tree. Therefore, it is impossible to implement iterators that is not invalidated.

Modules

attlistdecl
attr
character_data
document
document_fragment
document_type
dom_configuration
dom_error
dom_implementation
element
elementdecl
entity
entity_reference
name_list
named_node_map
node
node_list
notation
pi
user_data

Structs

DocumentPosition
Constants DocumentPosition in Interface Node.

Enums

DOMException
Implementation of DOMException interface on 1.4 Fundamental Interfaces: Core Module
NodeType
Constants NodeType in Interface Node.

Constants

XML_NS_NAMESPACE
XML_XML_NAMESPACE
This is the namespace for the special xml: prefix predefined in the XML Namespace specification.