pub struct Document { /* private fields */ }Expand description
Implementation of Document interface on 1.4 Fundamental Interfaces: Core Module
Implementations
Sourceimpl Document
impl Document
Sourcepub fn enable_read_only_check(&mut self)
pub fn enable_read_only_check(&mut self)
Enable check for read-only node.
As a result, editing of nodes specified as read-only in the DOM specification
becomes impossible.
Sourcepub fn disable_read_only_check(&mut self)
pub fn disable_read_only_check(&mut self)
Disable check for read-only node.
It allows editing of nodes that are not editable in the DOM specification
(e.g., DTD nodes).
Sourcepub fn is_enabled_read_only_check(&self) -> bool
pub fn is_enabled_read_only_check(&self) -> bool
Check if read-only check is enabled.
Sourcepub fn get_entity(&self, name: &str) -> Option<EntityRef>
pub fn get_entity(&self, name: &str) -> Option<EntityRef>
Do an entity lookup in the document entity hash table and returns the corresponding entity, otherwise a lookup is done in the predefined entities too.
If found, return found entity wrapped Some.
Otherwise, return None.