DocumentType

Struct DocumentType 

pub struct DocumentType { /* private fields */ }
Implementation of DocumentType interface on 1.5 Extended Interfaces: XML Module

Implementations

Source

impl DocumentType

pub fn get_entity(&self, name: &str) -> Option<EntityRef>

Return an entity that is specified by name if exists.

pub fn get_element_decl(&self, name: &str) -> Option<ElementDeclRef>

Return an elementdecl that is specified by name if exists.

pub fn add_entity<const EXT: bool>( &mut self, entity: EntityRef, ) -> Result<(), DOMException>

Add an entity.

If EXT is true, entity is added to the external subset, otherwise, added to the internal subset.

pub fn add_notation<const EXT: bool>( &mut self, notation: NotationRef, ) -> Result<(), DOMException>

Add a notation.

If EXT is true, entity is added to the external subset, otherwise, added to the internal subset.

pub fn add_element_decl<const EXT: bool>( &mut self, element_decl: ElementDeclRef, ) -> Result<(), DOMException>

Add a elementdecl.

If EXT is true, element_decl is added to the external subset, otherwise, added to the internal subset.

pub fn add_attlist_decl<const EXT: bool>( &mut self, attlist_decl: AttlistDeclRef, ) -> Result<(), DOMException>

Add a attlistdecl.

If EXT is true, attlist_decl is added to the external subset, otherwise, added to the internal subset.

pub fn owner_document(&self) -> Option<DocumentRef>