NameList

Struct NameList 

pub struct NameList { /* private fields */ }
Implementation of NameList interface on 1.4 Fundamental Interfaces: Core Module

The specification does not specify what orders the sets.
In this implementation, it is simply the order of insertion into the set.

Implementations

Source

impl NameList

pub fn get_name(&self, index: usize) -> Option<&str>

Implementation of getName method.

pub fn get_namespace_uri(&self, index: usize) -> Option<&str>

Implementation of getNamespaceURI method.

pub fn len(&self) -> usize

Implementation of length attribute.

pub fn is_empty(&self) -> bool

Check if this list is empty.
In other words, check self.len() == 0 is satisfied.

pub fn contains(&self, name: &str) -> bool

Implementation of contains method.

pub fn contains_ns(&self, ns_uri: Option<&str>, name: &str) -> bool

Implementation of containsNS method.