Node

Trait Node 

pub trait Node: NodeConnection {
Show 38 methods // Required methods fn node_name(&self) -> Rc<str>; fn node_value(&self) -> Option<Rc<str>>; fn set_node_value( &mut self, value: impl Into<String>, ) -> Result<(), DOMException>; fn node_type(&self) -> NodeType; fn clone_node(&self, deep: bool) -> NodeRef; fn is_same_node(&self, other: &NodeRef) -> bool; fn set_user_data( &mut self, key: impl Into<String>, data: DOMUserData, handler: Option<Arc<dyn UserDataHandler>>, ) -> Option<DOMUserData>; fn get_user_data(&self, key: &str) -> Option<DOMUserData>; fn is_read_only(&self) -> bool; // Provided methods fn parent_node(&self) -> Option<NodeRef> { ... } fn child_nodes(&self) -> ChildNodesList<NodeRef> { ... } fn first_child(&self) -> Option<NodeRef> { ... } fn last_child(&self) -> Option<NodeRef> { ... } fn previous_sibling(&self) -> Option<NodeRef> { ... } fn next_sibling(&self) -> Option<NodeRef> { ... } fn attributes(&self) -> Option<AttributeMap> { ... } fn owner_document(&self) -> Option<DocumentRef> { ... } fn insert_before( &mut self, new_child: NodeRef, ref_child: Option<NodeRef>, ) -> Result<NodeRef, DOMException> { ... } fn replace_child( &mut self, new_child: NodeRef, old_child: NodeRef, ) -> Result<NodeRef, DOMException> { ... } fn remove_child( &mut self, old_child: NodeRef, ) -> Result<NodeRef, DOMException> { ... } fn append_child( &mut self, new_child: NodeRef, ) -> Result<NodeRef, DOMException> { ... } fn has_child_nodes(&self) -> bool { ... } fn normalize(&mut self) { ... } fn is_supported(&self, feature: &str, version: Option<&str>) -> bool { ... } fn namespace_uri(&self) -> Option<Rc<str>> { ... } fn prefix(&self) -> Option<Rc<str>> { ... } fn set_prefix( &mut self, _prefix: Option<impl Into<Rc<str>>>, ) -> Result<(), DOMException> { ... } fn local_name(&self) -> Option<Rc<str>> { ... } fn has_attributes(&self) -> bool { ... } fn base_uri(&self) -> Option<String> { ... } fn compare_document_position(&self, other: &NodeRef) -> DocumentPosition { ... } fn text_content(&self) -> Option<String> { ... } fn set_text_content( &mut self, text: impl Into<String>, ) -> Result<(), DOMException> { ... } fn lookup_prefix(&self, namespace_uri: &str) -> Option<Rc<str>> { ... } fn is_default_namespace(&self, namespace_uri: &str) -> bool { ... } fn lookup_namespace_uri(&self, prefix: Option<&str>) -> Option<Rc<str>> { ... } fn is_equal_node(&self, arg: &NodeRef) -> bool { ... } fn get_feature(&self, feature: &str, version: Option<&str>) -> Option<Self> { ... }
}
Implementation of Node interface on 1.4 Fundamental Interfaces: Core Module

Actual node representations are implemented as NodeRef.

Required Methods

fn node_name(&self) -> Rc<str>

Implementation of nodeName attribute.

Specification
nodeName of type DOMString, readonly
    The name of this node, depending on its type; see the table above.
fn node_value(&self) -> Option<Rc<str>>

Implementation of nodeValue attribute.

Specification
nodeValue of type DOMString
    The value of this node, depending on its type; see the table above.
    When it is defined to be null, setting it has no effect, including
    if the node is read-only.

    Exceptions on retrieval
        DOMException
        DOMSTRING_SIZE_ERR: Raised when it would return more characters than fit
                            in a DOMString variable on the implementation platform.
fn set_node_value( &mut self, value: impl Into<String>, ) -> Result<(), DOMException>

Implementation of nodeValue attribute.

Specification
nodeValue of type DOMString
    The value of this node, depending on its type; see the table above.
    When it is defined to be null, setting it has no effect, including
    if the node is read-only.

    Exceptions on setting
        DOMException
        NO_MODIFICATION_ALLOWED_ERR: Raised when the node is readonly and
                                     if it is not defined to be null.
fn node_type(&self) -> NodeType

Implementation of nodeType attribute.

Specification
nodeType of type unsigned short, readonly
    A code representing the type of the underlying object, as defined above.
fn clone_node(&self, deep: bool) -> NodeRef

Implementation of cloneNode method.

Specification
Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes.
The duplicate node has no parent (parentNode is null) and no user data.
User data associated to the imported node is not carried over.
However, if any UserDataHandlers has been specified along with the associated data
these handlers will be called with the appropriate parameters before this method returns.
Cloning an Element copies all attributes and their values,
including those generated by the XML processor to represent defaulted attributes,
but this method does not copy any children it contains unless it is a deep clone.
This includes text contained in an the Element since the text is contained
in a child Text node. Cloning an Attr directly, as opposed to be cloned as part of
an Element cloning operation, returns a specified attribute (specified is true).
Cloning an Attr always clones its children, since they represent its value,
no matter whether this is a deep clone or not.
Cloning an EntityReference automatically constructs its subtree
if a corresponding Entity is available, no matter whether this is a deep clone or not.
Cloning any other type of node simply returns a copy of this node.
Note that cloning an immutable subtree results in a mutable copy,
but the children of an EntityReference clone are readonly.
In addition, clones of unspecified Attr nodes are specified.
And, cloning Document, DocumentType, Entity, and Notation nodes is implementation dependent.

Parameters
    deep of type boolean
        If true, recursively clone the subtree under the specified node;
        if false, clone only the node itself (and its attributes, if it is an Element).

Return Value
    Node The duplicate node.

No Exceptions
fn is_same_node(&self, other: &NodeRef) -> bool

Implementation of isSameNode method.

Specification
Returns whether this node is the same node as the given one.
This method provides a way to determine whether two Node references returned by the
implementation reference the same object. When two Node references are references to
the same object, even if through a proxy, the references may be used completely
interchangeably, such that all attributes have the same values and calling the same
DOM method on either reference always has exactly the same effect.

Parameters
    other of type Node
        The node to test against.

Return Value
    boolean Returns true if the nodes are the same, false otherwise.

No Exceptions
fn set_user_data( &mut self, key: impl Into<String>, data: DOMUserData, handler: Option<Arc<dyn UserDataHandler>>, ) -> Option<DOMUserData>

Implementation of setUserData method.

Specification
Associate an object to a key on this node. The object can later be retrieved
from this node by calling getUserData with the same key.

Parameters
    key of type DOMString
        The key to associate the object to.
    data of type DOMUserData
        The object to associate to the given key, or null to remove any
        existing association to that key.
    handler of type UserDataHandler
        The handler to associate to that key, or null.

Return Value
    DOMUserData Returns the DOMUserData previously associated to the given key
                on this node, or null if there was none.

No Exceptions
fn get_user_data(&self, key: &str) -> Option<DOMUserData>

Implementation of getUserData method.

Specification
Retrieves the object associated to a key on a this node. The object must first
have been set to this node by calling setUserData with the same key.

Parameters
    key of type DOMString
        The key the object is associated to.

Return Value
    DOMUserData Returns the DOMUserData associated to the given key on this node,
                or null if there was none.

No Exceptions
fn is_read_only(&self) -> bool

Check if this node is a read-only node.

This method is independent of the Document setting and always returns whether this node is read-only based on the DOM specification.

Provided Methods

fn parent_node(&self) -> Option<NodeRef>

Implementation of parentNode attribute.

Specification
parentNode of type Node, readonly
    The parent of this node. All nodes, except Attr, Document, DocumentFragment,
    Entity, and Notation may have a parent. However, if a node has just been
    created and not yet added to the tree, or if it has been removed from the tree,
    this is null.
fn child_nodes(&self) -> ChildNodesList<NodeRef>

Implementation of childNodes attribute.

Specification
childNodes of type NodeList, readonly
    A NodeList that contains all children of this node. If there are no children,
    this is a NodeList containing no nodes.
fn first_child(&self) -> Option<NodeRef>

Implementation of firstChild attribute.

Specification
firstChild of type Node, readonly
    The first child of this node. If there is no such node, this returns null.
fn last_child(&self) -> Option<NodeRef>

Implementation of lastChild attribute.

Specification
lastChild of type Node, readonly
    The last child of this node. If there is no such node, this returns null.
fn previous_sibling(&self) -> Option<NodeRef>

Implementation of previousSibling attribute.

Specification
previousSibling of type Node, readonly
    The node immediately preceding this node. If there is no such node,
    this returns null.
fn next_sibling(&self) -> Option<NodeRef>

Implementation of nextSibling attribute.

Specification
nextSibling of type Node, readonly
    The node immediately following this node. If there is no such node,
    this returns null.
fn attributes(&self) -> Option<AttributeMap>

Implementation of attributes attribute.

Specification
attributes of type NamedNodeMap, readonly
    A NamedNodeMap containing the attributes of this node (if it is an Element)
    or null otherwise.
fn owner_document(&self) -> Option<DocumentRef>

Implementation of ownerDocument attribute.

Specification
ownerDocument of type Document, readonly, modified in DOM Level 2
    The Document object associated with this node. This is also the Document object
    used to create new nodes. When this node is a Document or a DocumentType which
    is not used with any Document yet, this is null.
fn insert_before( &mut self, new_child: NodeRef, ref_child: Option<NodeRef>, ) -> Result<NodeRef, DOMException>

Implementation of insertBefore method.

If new_child and ref_child are same nodes, this method does nothing and return Ok(new_child).

Specification
Inserts the node newChild before the existing child node refChild.
If refChild is null, insert newChild at the end of the list of children.
If newChild is a DocumentFragment object, all of its children are inserted,
in the same order, before refChild.
If the newChild is already in the tree, it is first removed.

Note: Inserting a node before itself is implementation dependent.

Parameters
    newChild of type Node
        The node to insert.
    refChild of type Node
        The reference node, i.e., the node before which the new node must be inserted.

Return Value
    Node The node being inserted.

Exceptions
    DOMException
    HIERARCHY_REQUEST_ERR:       Raised if this node is of a type that does not allow
                                 children of the type of the newChild node, or if the
                                 node to insert is one of this node's ancestors or
                                 this node itself, or if this node is of type Document
                                 and the DOM application attempts to insert a second
                                 DocumentType or Element node.
    WRONG_DOCUMENT_ERR:          Raised if newChild was created from a different
                                 document than the one that created this node.
    NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly or if the parent of
                                 the node being inserted is readonly.
    NOT_FOUND_ERR:               Raised if refChild is not a child of this node.
    NOT_SUPPORTED_ERR:           if this node is of type Document, this exception
                                 might be raised if the DOM implementation doesn't
                                 support the insertion of a DocumentType or Element
                                 node.
fn replace_child( &mut self, new_child: NodeRef, old_child: NodeRef, ) -> Result<NodeRef, DOMException>

Implementation of replaceChild method.

Specification
Replaces the child node oldChild with newChild in the list of children,
and returns the oldChild node.  
If newChild is a DocumentFragment object, oldChild is replaced by all of
the DocumentFragment children, which are inserted in the same order.  
If the newChild is already in the tree, it is first removed.

Note: Replacing a node with itself is implementation dependent.

Parameters
    newChild of type Node
        The new node to put in the child list.
    oldChild of type Node
        The node being replaced in the list.

Return Value
    Node The node replaced.

Exceptions
    DOMException
    HIERARCHY_REQUEST_ERR:       Raised if this node is of a type that does not allow
                                 children of the type of the newChild node, or if the
                                 node to put in is one of this node's ancestors or
                                 this node itself, or if this node is of type Document
                                 and the result of the replacement operation would add
                                 a second DocumentType or Element on the Document node.
    WRONG_DOCUMENT_ERR:          Raised if newChild was created from a different
                                 document than the one that created this node.
    NO_MODIFICATION_ALLOWED_ERR: Raised if this node or the parent of the new node is
                                 readonly.
    NOT_FOUND_ERR:               Raised if oldChild is not a child of this node.
    NOT_SUPPORTED_ERR:           if this node is of type Document, this exception
                                 might be raised if the DOM implementation doesn't
                                 support the replacement of the DocumentType child or
                                 Element child.
fn remove_child(&mut self, old_child: NodeRef) -> Result<NodeRef, DOMException>

Implementation of removeChild method.

Specification
Removes the child node indicated by oldChild from the list of children, and returns it.

Parameters
    oldChild of type Node
        The node being removed.

Return Value
    Node The node removed.

Exceptions
    DOMException
    NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
    NOT_FOUND_ERR:               Raised if oldChild is not a child of this node.
    NOT_SUPPORTED_ERR:           if this node is of type Document, this exception
                                 might be raised if the DOM implementation doesn't
                                 support the removal of the DocumentType child or the
                                 Element child.
fn append_child(&mut self, new_child: NodeRef) -> Result<NodeRef, DOMException>

Implementation of appendChild method.

Specification
Adds the node newChild to the end of the list of children of this node.
If the newChild is already in the tree, it is first removed.

Parameters
    newChild of type Node
        The node to add.
        If it is a DocumentFragment object, the entire contents of
        the document fragment are moved into the child list of this node

Return Value
    Node The node added.

Exceptions
    DOMException
    HIERARCHY_REQUEST_ERR:       Raised if this node is of a type that does not allow
                                 children of the type of the newChild node, or if the
                                 node to append is one of this node's ancestors or
                                 this node itself, or if this node is of type Document
                                 and the DOM application attempts to append a second
                                 DocumentType or Element node.
    WRONG_DOCUMENT_ERR:          Raised if newChild was created from a different
                                 document than the one that created this node.
    NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly or if the previous
                                 parent of the node being inserted is readonly.
    NOT_SUPPORTED_ERR:           if the newChild node is a child of the Document node,
                                 this exception might be raised if the DOM
                                 implementation doesn't support the removal of the
                                 DocumentType child or Element child.
fn has_child_nodes(&self) -> bool

Implementation of hasChildNodes method.

Specification
Returns whether this node has any children.

Return Value
    boolean Returns true if this node has any children, false otherwise.

No Parameters
No Exceptions
fn normalize(&mut self)

Implementation of normalize method.

Specification
Puts all Text nodes in the full depth of the sub-tree underneath this Node, including
attribute nodes, into a "normal" form where only structure (e.g., elements, comments,
processing instructions, CDATA sections, and entity references) separates Text nodes,
i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to
ensure that the DOM view of a document is the same as if it were saved and re-loaded,
and is useful when operations (such as XPointer [XPointer] lookups) that depend on a
particular document tree structure are to be used. If the parameter
"normalize-characters" of the DOMConfiguration object attached to the
Node.ownerDocument is true, this method will also fully normalize the characters of
the Text nodes.

Note: In cases where the document contains CDATASections, the normalize operation
alone may not be sufficient, since XPointers do not differentiate between Text nodes
and CDATASection nodes.

No Parameters
No Return Value
No Exceptions
fn is_supported(&self, feature: &str, version: Option<&str>) -> bool

Implementation of isSupported attribute.

Specification
Tests whether the DOM implementation implements a specific feature and that feature
is supported by this node, as specified in DOM Features.

Parameters
    feature of type DOMString
        The name of the feature to test.
    version of type DOMString
        This is the version number of the feature to test.

Return Value
    boolean Returns true if the specified feature is supported on this node,
            false otherwise.

No Exceptions
fn namespace_uri(&self) -> Option<Rc<str>>

Implementation of namespaceURI attribute.

Specification
namespaceURI of type DOMString, readonly, introduced in DOM Level 2
    The namespace URI of this node, or null if it is unspecified (see XML Namespaces).
    This is not a computed value that is the result of a namespace lookup
    based on an examination of the namespace declarations in scope.
    It is merely the namespace URI given at creation time.
    For nodes of any type other than ELEMENT_NODE and ATTRIBUTE_NODE and
    nodes created with a DOM Level 1 method, such as Document.createElement(),
    this is always null.

    Note: Per the Namespaces in XML Specification [XML Namespaces] an attribute
    does not inherit its namespace from the element it is attached to.
    If an attribute is not explicitly given a namespace, it simply has no namespace.
fn prefix(&self) -> Option<Rc<str>>

Implementation of prefix attribute.

Specification
prefix of type DOMString, introduced in DOM Level 2
    The namespace prefix of this node, or null if it is unspecified. When it is
    defined to be null, setting it has no effect, including if the node is read-only.
    Note that setting this attribute, when permitted, changes the nodeName
    attribute, which holds the qualified name, as well as the tagName and name
    attributes of the Element and Attr interfaces, when applicable.
    Setting the prefix to null makes it unspecified, setting it to an empty string
    is implementation dependent.
    Note also that changing the prefix of an attribute that is known to have
    a default value, does not make a new attribute with the default value and the
    original prefix appear, since the namespaceURI and localName do not change.
    For nodes of any type other than ELEMENT_NODE and ATTRIBUTE_NODE and nodes
    created with a DOM Level 1 method, such as createElement from the Document
    interface, this is always null.
fn set_prefix( &mut self, _prefix: Option<impl Into<Rc<str>>>, ) -> Result<(), DOMException>

Implementation of prefix attribute.

Specification
prefix of type DOMString, introduced in DOM Level 2
    The namespace prefix of this node, or null if it is unspecified. When it is
    defined to be null, setting it has no effect, including if the node is read-only.
    Note that setting this attribute, when permitted, changes the nodeName
    attribute, which holds the qualified name, as well as the tagName and name
    attributes of the Element and Attr interfaces, when applicable.
    Setting the prefix to null makes it unspecified, setting it to an empty string
    is implementation dependent.
    Note also that changing the prefix of an attribute that is known to have
    a default value, does not make a new attribute with the default value and the
    original prefix appear, since the namespaceURI and localName do not change.
    For nodes of any type other than ELEMENT_NODE and ATTRIBUTE_NODE and nodes
    created with a DOM Level 1 method, such as createElement from the Document
    interface, this is always null.

    Exceptions on setting
        DOMException
        INVALID_CHARACTER_ERR:       Raised if the specified prefix contains an
                                     illegal character according to the XML version
                                     in use specified in the Document.xmlVersion
                                     attribute.
        NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
        NAMESPACE_ERR:               Raised if the specified prefix is malformed
                                     per the Namespaces in XML specification, if
                                     the namespaceURI of this node is null, if the
                                     specified prefix is "xml" and the namespaceURI
                                     of this node is different from
                                     "http://www.w3.org/XML/1998/namespace", if this
                                     node is an attribute and the specified prefix
                                     is "xmlns" and the namespaceURI of this node is
                                     different from "http://www.w3.org/2000/xmlns/",
                                     or if this node is an attribute and the
                                     qualifiedName of this node is "xmlns"
                                     [XML Namespaces].
fn local_name(&self) -> Option<Rc<str>>

Implementation of localName attribute.

Specification
localName of type DOMString, readonly, introduced in DOM Level 2
    Returns the local part of the qualified name of this node.
    For nodes of any type other than ELEMENT_NODE and ATTRIBUTE_NODE and nodes
    created with a DOM Level 1 method, such as Document.createElement(), this is
    always null.
fn has_attributes(&self) -> bool

Implementation of hasAttributes method.

Specification
Returns whether this node (if it is an element) has any attributes.

Return Value
    boolean Returns true if this node has any attributes, false otherwise.
fn base_uri(&self) -> Option<String>

Implementation of baseURI attribute.

Specification
baseURI of type DOMString, readonly, introduced in DOM Level 3
    The absolute base URI of this node or null if the implementation wasn't able
    to obtain an absolute URI. This value is computed as described in Base URIs.
    However, when the Document supports the feature "HTML" [DOM Level 2 HTML],
    the base URI is computed using first the value of the href attribute
    of the HTML BASE element if any, and the value of the documentURI attribute
    from the Document interface otherwise.
fn compare_document_position(&self, other: &NodeRef) -> DocumentPosition

Implementation of compareDocumentPosition method.

Specification
Compares the reference node, i.e. the node on which this method is being called,
with a node, i.e. the one passed as a parameter, with regard to their position
in the document and according to the document order.

Parameters
    other of type Node
        The node to compare against the reference node.

Return Value
    unsigned short Returns how the node is positioned relatively to the reference
                   node.

Exceptions
    DOMException
    NOT_SUPPORTED_ERR: when the compared nodes are from different DOM implementations
                       that do not coordinate to return consistent
                       implementation-specific results.
fn text_content(&self) -> Option<String>

Implementation of textContent attribute.

Specification
textContent of type DOMString, introduced in DOM Level 3
    This attribute returns the text content of this node and its descendants.
    When it is defined to be null, setting it has no effect. On setting, any
    possible children this node may have are removed and, if it the new string is
    not empty or null, replaced by a single Text node containing the string this
    attribute is set to.
    On getting, no serialization is performed, the returned string does not contain
    any markup. No whitespace normalization is performed and the returned string
    does not contain the white spaces in element content (see the attribute
    Text.isElementContentWhitespace). Similarly, on setting, no parsing is performed
    either, the input string is taken as pure textual content.
    The string returned is made of the text content of this node depending on its
    type, as defined below:

    <omitted>

    Exceptions on retrieval
        DOMException
        DOMSTRING_SIZE_ERR: Raised when it would return more characters than fit
                            in a DOMString variable on the implementation platform.
fn set_text_content( &mut self, text: impl Into<String>, ) -> Result<(), DOMException>

Implementation of textContent attribute.

Specification
textContent of type DOMString, introduced in DOM Level 3
    This attribute returns the text content of this node and its descendants.
    When it is defined to be null, setting it has no effect. On setting, any
    possible children this node may have are removed and, if it the new string is
    not empty or null, replaced by a single Text node containing the string this
    attribute is set to.
    On getting, no serialization is performed, the returned string does not contain
    any markup. No whitespace normalization is performed and the returned string
    does not contain the white spaces in element content (see the attribute
    Text.isElementContentWhitespace). Similarly, on setting, no parsing is performed
    either, the input string is taken as pure textual content.
    The string returned is made of the text content of this node depending on its
    type, as defined below:

    <omitted>

    Exceptions on setting
        DOMException
        NO_MODIFICATION_ALLOWED_ERR: Raised when the node is readonly.
fn lookup_prefix(&self, namespace_uri: &str) -> Option<Rc<str>>

Implementation of lookupPrefix method.

The implementation was based on Appendix B.2 Namespace Prefix Lookup.

Specification
Look up the prefix associated to the given namespace URI, starting from this node.
The default namespace declarations are ignored by this method.
See Namespace Prefix Lookup for details on the algorithm used by this method.

Parameters
    namespaceURI of type DOMString
        The namespace URI to look for.

Return Value
    DOMString Returns an associated namespace prefix if found or null if none is
              found. If more than one prefix are associated to the namespace prefix,
              the returned namespace prefix is implementation dependent.

No Exceptions
fn is_default_namespace(&self, namespace_uri: &str) -> bool

Implementation of isDefaultNamespace method.

The implementation was based on Appendix B.3 Default Namespace Lookup.

Specification
This method checks if the specified namespaceURI is the default namespace or not.

Parameters
    namespaceURI of type DOMString
        The namespace URI to look for.

Return Value
    boolean Returns true if the specified namespaceURI is the default namespace,
            false otherwise.

No Exceptions
fn lookup_namespace_uri(&self, prefix: Option<&str>) -> Option<Rc<str>>

Implementation of lookupNamespaceURI method.

The implementation was based on Appendix B.4 Namespace URI Lookup.

Specification
Look up the namespace URI associated to the given prefix, starting from this node.
See Namespace URI Lookup for details on the algorithm used by this method.

Parameters
    prefix of type DOMString
        The prefix to look for. If this parameter is null, the method will return
        the default namespace URI if any.

Return Value
    DOMString Returns the associated namespace URI or null if none is found.

No Exceptions
fn is_equal_node(&self, arg: &NodeRef) -> bool

Implementation of isEqualNode method.

Note

Normalization can affect equality, but this method does not normalize nodes.
If need, the caller should normalize nodes before calling this method.

Specification
Tests whether two nodes are equal.
This method tests for equality of nodes, not sameness
(i.e., whether the two nodes are references to the same object)
which can be tested with Node.isSameNode().
All nodes that are the same will also be equal, though the reverse may not be true.
Two nodes are equal if and only if the following conditions are satisfied:

- The two nodes are of the same type.
- The following string attributes are equal: nodeName, localName, namespaceURI,
  prefix, nodeValue. This is: they are both null, or they have the same length
  and are character for character identical.
- The attributes NamedNodeMaps are equal.
  This is: they are both null, or they have the same length and for each node
  that exists in one map there is a node that exists in the other map and is equal,
  although not necessarily at the same index.
- The childNodes NodeLists are equal.
  This is: they are both null, or they have the same length and contain equal nodes
  at the same index. Note that normalization can affect equality;
  to avoid this, nodes should be normalized before being compared.

For two DocumentType nodes to be equal, the following conditions must also be satisfied:

- The following string attributes are equal: publicId, systemId, internalSubset.
- The entities NamedNodeMaps are equal.
- The notations NamedNodeMaps are equal.

On the other hand, the following do not affect equality: the ownerDocument,
baseURI, and parentNode attributes, the specified attribute for Attr nodes,
the schemaTypeInfo attribute for Attr and Element nodes,
the Text.isElementContentWhitespace attribute for Text nodes, as well as any user data
or event listeners registered on the nodes.

Note: As a general rule, anything not mentioned in the description above
      is not significant in consideration of equality checking.
      Note that future versions of this specification may take into account
      more attributes and implementations conform to this specification are expected
      to be updated accordingly.

Parameters
    arg of type Node
        The node to compare equality with.

Return Value
    boolean Returns true if the nodes are equal, false otherwise.
fn get_feature(&self, feature: &str, version: Option<&str>) -> Option<Self>

Implementation of getFeature method.

Note

In this crate, this method simply clones and returns self if DOMImplementation::has_feature returns true.
Since cast possibilities are uniquely determined by the type implementation, there is basically no need to use this method.

Specification
This method returns a specialized object which implements the specialized APIs of the specified feature and version, as specified in DOM Features. The specialized object may also be obtained by using binding-specific casting methods but is not necessarily expected to, as discussed in Mixed DOM Implementations. This method also allow the implementation to provide specialized objects which do not support the Node interface.

Parameters
    feature of type DOMString
        The name of the feature requested. Note that any plus sign "+" prepended to the name of the feature will be ignored since it is not significant in the context of this method.
    version of type DOMString
        This is the version number of the feature to test.

Return Value
    DOMObject Returns an object which implements the specialized APIs of the
              specified feature and version, if any, or null if there is no
              object which implements interfaces associated with that feature.
              If the DOMObject returned by this method implements the Node
              interface, it must delegate to the primary core Node and not return
              results inconsistent with the primary core Node such as attributes,
              childNodes, etc.

No Exceptions

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors