pub fn html_element_status_here(
parent: &HtmlElemDesc,
elt: &HtmlElemDesc,
) -> HtmlStatusExpand description
Checks whether an HTML element may be a direct child of a parent element. and if so whether it is valid or deprecated.
Returns one of htmlStatus::HTML_VALID, htmlStatus::HTML_DEPRECATED, htmlStatus::HTML_INVALID