xml_load_catalogs

Function xml_load_catalogs 

pub fn xml_load_catalogs(pathss: &str)
Load the catalogs and makes their definitions effective for the default external entity loader.

This function is not thread safe, catalog initialization should preferably be done once at startup