pub unsafe extern "C" fn xml_new_mutex() -> XmlMutexPtrExpand description
xmlNewMutex() is used to allocate a libxml2 token struct for use in synchronizing access to data.
Returns a new simple mutex pointer or NULL in case of error
pub unsafe extern "C" fn xml_new_mutex() -> XmlMutexPtrxmlNewMutex() is used to allocate a libxml2 token struct for use in synchronizing access to data.
Returns a new simple mutex pointer or NULL in case of error