xml_schema_validate_one_element

Function xml_schema_validate_one_element 

pub unsafe fn xml_schema_validate_one_element(
    ctxt: XmlSchemaValidCtxtPtr<'_>,
    elem: XmlNodePtr,
) -> i32
Validate a branch of a tree, starting with the given @elem.

Returns 0 if the element and its subtree is valid, a positive error code number otherwise and -1 in case of an internal or API error.