Module nanohttp

Module nanohttp 

Provide methods and data structures for handling HTTP.

This module is based on libxml/nanohttp.h, nanohttp.c, and so on in libxml2-v2.11.8.
Please refer to original libxml2 documents also.

Structs

XmlNanoHTTPCtxt

Functions

xml_nanohttp_auth_header
Get the authentication header of an HTTP context
xml_nanohttp_cleanup
Cleanup the HTTP protocol layer.
xml_nanohttp_content_length
Provides the specified content length from the HTTP header.
xml_nanohttp_fetch
This function try to fetch the indicated resource via HTTP GET and save it’s content in the file.
xml_nanohttp_init
Initialize the HTTP protocol layer. Currently it just checks for proxy information
xml_nanohttp_method
This function try to open a connection to the indicated resource via HTTP using the given @method, adding the given extra headers and the input buffer for the request content.
xml_nanohttp_method_redir
This function try to open a connection to the indicated resource via HTTP using the given @method, adding the given extra headers and the input buffer for the request content.
xml_nanohttp_open_redir
This function try to open a connection to the indicated resource via HTTP GET.
xml_nanohttp_read
This function tries to read @len bytes from the existing HTTP connection and saves them in @dest. This is a blocking call.
xml_nanohttp_save
This function saves the output of the HTTP transaction to a file It closes and free the context at the end
xml_nanohttp_scan_proxy
(Re)Initialize the HTTP Proxy context by parsing the URL and finding the protocol host port it indicates. Should be like http://myproxy/ or http://myproxy:3128/ A NULL URL cleans up proxy information.