xml_recover_memory

Function xml_recover_memory 

pub fn xml_recover_memory(buffer: &[u8]) -> Option<XmlDocPtr>
👎Deprecated: Use xmlReadMemory with XML_PARSE_RECOVER
Parse an XML in-memory block and build a tree. In the case the document is not Well Formed, an attempt to build a tree is tried anyway

Returns the resulting document tree or NULL in case of error