StartElementNsSAX2Func

Type Alias StartElementNsSAX2Func 

pub type StartElementNsSAX2Func = fn(&mut XmlParserCtxt<'_>, &str, Option<&str>, Option<&str>, &[(Option<String>, String)], usize, &[(String, Option<String>, Option<String>, String)]);
SAX2 callback when an element start has been detected by the parser. It provides the namespace information for the element, as well as the new namespace declarations on the element.