xml_new_doc_node

Function xml_new_doc_node 

pub fn xml_new_doc_node(
    doc: Option<XmlDocPtr>,
    ns: Option<XmlNsPtr>,
    name: &str,
    content: Option<&str>,
) -> Option<XmlNodePtr>
Creation of a new node element within a document. @ns and @content are optional (null_mut()). NOTE: @content is supposed to be a piece of XML CDATA, so it allow entities references, but XML special chars need to be escaped first by using xmlEncodeEntitiesReentrant(). Use xmlNewDocRawNode() if you don’t need entities support.

Returns a pointer to the new node object.