xml_new_ns

Function xml_new_ns 

pub fn xml_new_ns(
    node: Option<XmlNodePtr>,
    href: Option<&str>,
    prefix: Option<&str>,
) -> Option<XmlNsPtr>
Creation of a new Namespace. This function will refuse to create a namespace with a similar prefix than an existing one present on this node. Note that for a default namespace, prefix should be NULL.

We use href == NULL in the case of an element creation where the namespace was not defined.

Returns a new namespace pointer or NULL