canonic_path

Function canonic_path 

pub fn canonic_path(path: &str) -> Cow<'_, str>
Returns a new canonic path, or a duplicate of the path parameter if the construction fails. The caller is responsible for freeing the memory occupied by the returned string. If there is insufficient memory available, or the argument is NULL, the function returns NULL.