XmlSchemaParserCtxt

Struct XmlSchemaParserCtxt 

pub struct XmlSchemaParserCtxt<'a> { /* private fields */ }

Implementations

Source

impl XmlSchemaParserCtxt<'_>

pub unsafe fn get_errors( &self, err: Option<&mut Option<GenericError>>, warn: Option<&mut Option<GenericError>>, ctx: Option<&mut Option<GenericErrorContext>>, ) -> i32

Get the callback information used to handle errors for a parser context

Returns -1 in case of failure, 0 otherwise

pub unsafe fn set_errors( &mut self, err: Option<GenericError>, warn: Option<GenericError>, ctx: Option<GenericErrorContext>, )

Set the callback functions used to handle errors for a validation context

pub unsafe fn set_structured_errors( &mut self, serror: Option<StructuredError>, ctx: Option<GenericErrorContext>, )

Set the structured error callback

Source

impl XmlSchemaParserCtxt<'_>

pub unsafe fn parse(&mut self) -> XmlSchemaPtr

parse a schema definition resource and build an internal XML Schema structure which can be used to validate instances.

Returns the internal XML Schema structure built from the resource or NULL in case of error