xml_xpath_next_preceding

Function xml_xpath_next_preceding 

pub fn xml_xpath_next_preceding(
    ctxt: &mut XmlXPathParserContext<'_>,
    cur: Option<XmlGenericNodePtr>,
) -> Option<XmlGenericNodePtr>
Traversal function for the “preceding” direction the preceding axis contains all nodes in the same document as the context node that are before the context node in document order, excluding any ancestors and excluding attribute nodes and namespace nodes; the nodes are ordered in reverse document order

Returns the next element following that axis