Module node_set

Module node_set 

Structs

XmlNodeSet
A node-set (an unordered collection of nodes without duplicates).

Functions

xml_xpath_difference
Implements the EXSLT - Sets difference() function: node-set set:difference (node-set, node-set)
xml_xpath_distinct
Implements the EXSLT - Sets distinct() function: node-set set:distinct (node-set) @nodes is sorted by document order, then #exslSetsDistinctSorted is called with the sorted node-set
xml_xpath_distinct_sorted
Implements the EXSLT - Sets distinct() function: node-set set:distinct (node-set)
xml_xpath_free_node_set
Free the NodeSet compound (not the actual nodes !).
xml_xpath_free_value_tree
Free the NodeSet compound and the actual tree, this is different from xmlXPathFreeNodeSet()
xml_xpath_leading
Implements the EXSLT - Sets leading() function: node-set set:leading (node-set, node-set) @nodes1 and @nodes2 are sorted by document order, then #exslSetsLeadingSorted is called.
xml_xpath_leading_sorted
Implements the EXSLT - Sets leading() function: node-set set:leading (node-set, node-set)
xml_xpath_new_node_set_list
Create a new xmlXPathObjectPtr of type NodeSet and initialize it with the Nodeset @val
xml_xpath_node_leading
Implements the EXSLT - Sets leading() function: node-set set:leading (node-set, node-set) @nodes is sorted by document order, then #exslSetsNodeLeadingSorted is called.
xml_xpath_node_leading_sorted
Implements the EXSLT - Sets leading() function: node-set set:leading (node-set, node-set)
xml_xpath_node_set_create
Create a new xmlNodeSetPtr of type f64 and of value @val
xml_xpath_node_set_merge
Merges two nodesets, all nodes from @val2 are added to @val1 if @val1 is NULL, a new set is created and copied from @val2
xml_xpath_node_trailing
Implements the EXSLT - Sets trailing() function: node-set set:trailing (node-set, node-set) @nodes is sorted by document order, then #xmlXPathNodeTrailingSorted is called.
xml_xpath_node_trailing_sorted
Implements the EXSLT - Sets trailing() function: node-set set:trailing (node-set, node-set)
xml_xpath_trailing
Implements the EXSLT - Sets trailing() function: node-set set:trailing (node-set, node-set) @nodes1 and @nodes2 are sorted by document order, then #xmlXPathTrailingSorted is called.
xml_xpath_trailing_sorted
Implements the EXSLT - Sets trailing() function: node-set set:trailing (node-set, node-set)