XmlNodeSet

Struct XmlNodeSet 

#[repr(C)]
pub struct XmlNodeSet { pub node_tab: Vec<XmlGenericNodePtr>, }
A node-set (an unordered collection of nodes without duplicates).

Fields

node_tab: Vec<XmlGenericNodePtr>

Implementations

Source

impl XmlNodeSet

pub fn with_value(val: Option<XmlGenericNodePtr>) -> Option<Self>

pub fn contains(&self, val: Option<XmlGenericNodePtr>) -> bool

checks whether @cur contains @val

Returns true (1) if @cur contains @val, false (0) otherwise

pub unsafe fn has_same_nodes(&self, other: &XmlNodeSet) -> bool

Implements the EXSLT - Sets has-same-nodes function: boolean set:has-same-node(node-set, node-set)

Returns true (1) if @nodes1 shares any node with @nodes2, false (0) otherwise

pub fn intersection(&self, other: &XmlNodeSet) -> Option<Box<XmlNodeSet>>

Implements the EXSLT - Sets intersection() function: node-set set:intersection (node-set, node-set)

Returns a node set comprising the nodes that are within both the node sets passed as arguments

pub fn sort(&mut self)

Sort the node set in document order

pub fn remove(&mut self, val: i32)

Removes an entry from an existing NodeSet list.

pub fn delete(&mut self, val: XmlGenericNodePtr)

Removes an xmlNodePtr from an existing NodeSet

pub fn add(&mut self, val: XmlGenericNodePtr) -> i32

Add a new xmlNodePtr to an existing NodeSet

Returns 0 in case of success, and -1 in case of error

pub fn add_unique(&mut self, val: XmlGenericNodePtr) -> i32

Add a new xmlNodePtr to an existing NodeSet, optimized version when we are sure the node is not already in the set.

Returns 0 in case of success and -1 in case of failure

pub fn add_ns(&mut self, node: XmlNodePtr, ns: XmlNsPtr) -> i32

Add a new namespace node to an existing NodeSet

Returns 0 in case of success and -1 in case of error