pub type XmlXPathEvalFunc = fn(ctxt: &mut XmlXPathParserContext<'_>, nargs: i32);Expand description
An XPath evaluation function, the parameters are on the XPath context stack.
pub type XmlXPathEvalFunc = fn(ctxt: &mut XmlXPathParserContext<'_>, nargs: i32);An XPath evaluation function, the parameters are on the XPath context stack.