xml_xptr_range_to_function

Function xml_xptr_range_to_function 

pub fn xml_xptr_range_to_function(
    ctxt: &mut XmlXPathParserContext<'_>,
    _nargs: i32,
)
Implement the range-to() XPointer function

Obsolete. range-to is not a real function but a special type of location step which is handled in xpath.c.