Provide methods and data structures for debug XML documents.
This module is based on libxml/debugXML.h, debugXML.c, and so on in libxml2-v2.11.8.
Please refer to original libxml2 documents also.
Structs
- XmlDebug
Ctxt - XmlShell
Ctxt - A debugging shell context.
TODO: add the defined function tables.
Functions
- xml_
bool_ to_ text - Convenient way to turn bool into text
- xml_
debug_ check_ document - Check the document for potential content problems, and output
the errors to
output - xml_
debug_ dump_ attr - Dumps debug information for the attribute
- xml_
debug_ dump_ attr_ list - Dumps debug information for the attribute list
- xml_
debug_ dump_ document - Dumps debug information for the document, it’s recursive
- xml_
debug_ dump_ document_ head - Dumps debug information concerning the document, not recursive
- xml_
debug_ dump_ dtd - Dumps debug information for the DTD
- xml_
debug_ dump_ entities - Dumps debug information for all the entities in use by the document
- xml_
debug_ dump_ node - Dumps debug information for the element node, it is recursive
- xml_
debug_ dump_ node_ list - Dumps debug information for the list of element node, it is recursive
- xml_
debug_ dump_ one_ node - Dumps debug information for the element node, it is not recursive
- xml_
debug_ dump_ string - Dumps information about the string, shorten it if necessary
- xml_
ls_ count_ node - Count the children of @node.
- xml_
ls_ one_ node - Dump to
outputthe type and name of @node. - xml_
shell ⚠ - Implements the XML shell This allow to load, validate, view, modify and save a document using a environment similar to a UNIX commandline.
- xml_
shell_ ⚠print_ node - Print node to the output FILE
- xml_
shell_ print_ xpath_ error - Print the xpath error to libxml default error channel
- xml_
shell_ ⚠print_ xpath_ result - Prints result to the output FILE
Type Aliases
- XmlDebug
Ctxt Ptr - XmlShell
Cmd - This is a generic signature for the XML shell functions.
- XmlShell
Readline Func - This is a generic signature for the XML shell input function.