pub trait DOMImplementationSource:
Send
+ Sync
+ 'static {
// Required methods
fn get_dom_implementation(
&self,
features: &str,
) -> Option<Arc<dyn DOMImplementation>>;
fn get_dom_implementation_list(
&self,
features: &str,
) -> Arc<dyn DOMImplementationList>;
}Expand description
Implementation of DOMImpelmentationSource interface.
Required Methods
Sourcefn get_dom_implementation(
&self,
features: &str,
) -> Option<Arc<dyn DOMImplementation>>
fn get_dom_implementation( &self, features: &str, ) -> Option<Arc<dyn DOMImplementation>>
Implementation of getDOMImplementation method.
Specification
A method to request the first DOM implementation that supports the specified features.
Parameters
features of type DOMString
A string that specifies which features and versions are required. This is a
space separated list in which each feature is specified by its name optionally
followed by a space and a version number.
This method returns the first item of the list returned by
getDOMImplementationList.
As an example, the string "XML 3.0 Traversal +Events 2.0" will request
a DOM implementation that supports the module "XML" for its 3.0 version,
a module that support of the "Traversal" module for any version, and the module
"Events" for its 2.0 version. The module "Events" must be accessible using
the method Node.getFeature() and DOMImplementation.getFeature().
Return Value
DOMImplementation The first DOM implementation that support the desired features,
or null if this source has none.
No ExceptionsSourcefn get_dom_implementation_list(
&self,
features: &str,
) -> Arc<dyn DOMImplementationList>
fn get_dom_implementation_list( &self, features: &str, ) -> Arc<dyn DOMImplementationList>
Implementation of getDOMImplementationList method.
Specification
A method to request a list of DOM implementations that support the specified features
and versions, as specified in DOM Features.
Parameters
features of type DOMString
A string that specifies which features and versions are required.
This is a space separated list in which each feature is specified by its name
optionally followed by a space and a version number. This is something like:
"XML 3.0 Traversal +Events 2.0"
Return Value
DOMImplementationList A list of DOM implementations that support the desired
features.
No Exceptions