pub struct NameList { /* private fields */ }Expand description
Implementation of NameList interface on 1.4 Fundamental Interfaces: Core Module
The specification does not specify what orders the sets.
In this implementation, it is simply the order of insertion into the set.
Implementations