pub enum EncodingError {
BufferTooShort,
Malformed {
read: usize,
write: usize,
length: usize,
offset: usize,
},
Unmappable {
read: usize,
write: usize,
c: char,
},
Other {
msg: Cow<'static, str>,
},
}Variants
BufferTooShort
The length of the output buffer is too short.
If this error is returned, it is guaranteed that the encoder/decoder is consuming the input buffer.
Malformed
Malformed byte sequence is found.
The input and output buffer have consumed read and write bytes respectively.
Malformed sequence occurs input[read-length-offset..read-offset].
Only the decoder returns this error.
Unmappable
A UTF-8 character c cannot map any codepoints of the target encoding.
The input and output buffer have consumed read and write bytes respectively.
read includes the length of c. Thus, the correctly read length is read - c.len_utf8().
write does not include the length of c because encoder cannot write unmapped characters.
Only the encoder returns this error.
Other
Other errors.
Implementations
Sourceimpl EncodingError
impl EncodingError