pub fn xml_load_catalogs(pathss: &str)Expand description
Load the catalogs and makes their definitions effective for the default external entity loader.
This function is not thread safe, catalog initialization should preferably be done once at startup