Provide methods and data structures for handling HTTP.
This module is based on libxml/nanohttp.h, nanohttp.c, and so on in libxml2-v2.11.8.
Please refer to original libxml2 documents also.
Structs
Functions
- xml_
nanohttp_ auth_ header - Get the authentication header of an HTTP context
- xml_
nanohttp_ cleanup - Cleanup the HTTP protocol layer.
- xml_
nanohttp_ content_ length - Provides the specified content length from the HTTP header.
- xml_
nanohttp_ fetch - This function try to fetch the indicated resource via HTTP GET and save it’s content in the file.
- xml_
nanohttp_ init - Initialize the HTTP protocol layer. Currently it just checks for proxy information
- xml_
nanohttp_ method - This function try to open a connection to the indicated resource via HTTP using the given @method, adding the given extra headers and the input buffer for the request content.
- xml_
nanohttp_ method_ redir - This function try to open a connection to the indicated resource via HTTP using the given @method, adding the given extra headers and the input buffer for the request content.
- xml_
nanohttp_ open_ redir - This function try to open a connection to the indicated resource via HTTP GET.
- xml_
nanohttp_ read - This function tries to read @len bytes from the existing HTTP connection and saves them in @dest. This is a blocking call.
- xml_
nanohttp_ save - This function saves the output of the HTTP transaction to a file It closes and free the context at the end
- xml_
nanohttp_ scan_ proxy - (Re)Initialize the HTTP Proxy context by parsing the URL and finding the protocol host port it indicates. Should be like http://myproxy/ or http://myproxy:3128/ A NULL URL cleans up proxy information.