pub struct XmlAttr {
pub _private: *mut c_void,
pub name: Box<str>,
pub next: Option<XmlAttrPtr>,
pub ns: Option<XmlNsPtr>,
/* private fields */
}Fields
_private: *mut c_voidname: Box<str>next: Option<XmlAttrPtr>ns: Option<XmlNsPtr>Implementations
Sourceimpl XmlAttr
impl XmlAttr
Sourcepub fn search_ns_by_href(
&mut self,
doc: Option<XmlDocPtr>,
href: &str,
) -> Option<XmlNsPtr>
pub fn search_ns_by_href( &mut self, doc: Option<XmlDocPtr>, href: &str, ) -> Option<XmlNsPtr>
Search a Ns aliasing a given URI. Recurse on the parents until it finds the defined namespace or return NULL otherwise.
Returns the namespace pointer or NULL.
Sourcepub fn get_content(&self) -> Option<String>
pub fn get_content(&self) -> Option<String>
Read the value of a node, this can be either the text carried directly by this node if it’s a TEXT node or the aggregate string of the values carried by this node child’s (TEXT and ENTITY_REF).
Entity references are substituted.
Returns a new #XmlChar * or null_mut() if no content is available.
It’s up to the caller to free the memory with xml_free().
Sourcepub fn get_content_to(&self, buf: &mut String) -> i32
pub fn get_content_to(&self, buf: &mut String) -> i32
Read the value of a node cur, this can be either the text carried
directly by this node if it’s a TEXT node or the aggregate string
of the values carried by this node child’s (TEXT and ENTITY_REF).
Entity references are substituted. Fills up the buffer buf with this value.
Returns 0 in case of success and -1 in case of error.