Provide methods and data structures for text writing APIs.
This module is based on libxml/xmlwriter.h, xmlwriter.c and so on in libxml2-v2.11.8.
Please refer to original libxml2 documents also.
The original API has functions that support the format, but not here.
Although Rust has no variable-length arguments,
it is simpler and more natural to limit the API to writing a single string,
since it is easy to write the format to a single String using format!.