#[repr(C)]pub struct XmlNodeSet {
pub node_tab: Vec<XmlGenericNodePtr>,
}Expand description
A node-set (an unordered collection of nodes without duplicates).
Fields
node_tab: Vec<XmlGenericNodePtr>Implementations
Sourceimpl XmlNodeSet
impl XmlNodeSet
pub fn with_value(val: Option<XmlGenericNodePtr>) -> Option<Self>
Sourcepub fn contains(&self, val: Option<XmlGenericNodePtr>) -> bool
pub fn contains(&self, val: Option<XmlGenericNodePtr>) -> bool
checks whether @cur contains @val
Returns true (1) if @cur contains @val, false (0) otherwise
Sourcepub unsafe fn has_same_nodes(&self, other: &XmlNodeSet) -> bool
pub unsafe fn has_same_nodes(&self, other: &XmlNodeSet) -> bool
Implements the EXSLT - Sets has-same-nodes function: boolean set:has-same-node(node-set, node-set)
Returns true (1) if @nodes1 shares any node with @nodes2, false (0) otherwise
Sourcepub fn intersection(&self, other: &XmlNodeSet) -> Option<Box<XmlNodeSet>>
pub fn intersection(&self, other: &XmlNodeSet) -> Option<Box<XmlNodeSet>>
Implements the EXSLT - Sets intersection() function: node-set set:intersection (node-set, node-set)
Returns a node set comprising the nodes that are within both the node sets passed as arguments
Sourcepub fn delete(&mut self, val: XmlGenericNodePtr)
pub fn delete(&mut self, val: XmlGenericNodePtr)
Removes an xmlNodePtr from an existing NodeSet
Sourcepub fn add(&mut self, val: XmlGenericNodePtr) -> i32
pub fn add(&mut self, val: XmlGenericNodePtr) -> i32
Add a new xmlNodePtr to an existing NodeSet
Returns 0 in case of success, and -1 in case of error
Sourcepub fn add_unique(&mut self, val: XmlGenericNodePtr) -> i32
pub fn add_unique(&mut self, val: XmlGenericNodePtr) -> i32
Add a new xmlNodePtr to an existing NodeSet, optimized version when we are sure the node is not already in the set.
Returns 0 in case of success and -1 in case of failure
Sourcepub fn add_ns(&mut self, node: XmlNodePtr, ns: XmlNsPtr) -> i32
pub fn add_ns(&mut self, node: XmlNodePtr, ns: XmlNsPtr) -> i32
Add a new namespace node to an existing NodeSet
Returns 0 in case of success and -1 in case of error